TCompleterQueue class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
{bool doTryCompleteAll = false}) → void -
lockAndRun<
T> ({required FutureOr< T> run(VoidCallback unlock), Object? completerId}) → FutureOr<T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerCompleter(
Object id) → Completer -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited